import * as complugin from 'complugin';
import { TransformOptions } from '@babel/core';

declare type BabelOptions = Omit<TransformOptions, 'fileName' | 'minify' | 'include' | 'exclude'>;
declare namespace compluginBabel {
    interface Options extends BabelOptions {
        /**
         * A minimatch pattern, or array of patterns,
         * which specifies the files in the build the plugin should ignore.
         *
         * When relying on Babel configuration files you can only exclude additional files with this option,
         * you cannot override what you have configured for Babel itself.
         *
         * @default [/\.(tsx?|jsx?|mjs)$/i]
         */
        include?: (string | RegExp)[];
        /**
         * A minimatch pattern, or array of patterns, which specifies the files in the build the plugin should operate on.
         * When relying on Babel configuration files you cannot include files already excluded there.
         */
        exclude?: (string | RegExp)[];
        /**
         * Cache the transform results of Babel.
         *
         * @default true
         */
        cache?: boolean;
    }
}
declare const compluginBabel: complugin.CompluginInstance<compluginBabel.Options>;

export { compluginBabel as default };
